</br>
<div class="row">
	<div class=" col-md-offset-2 col-md-8">
		<div class="panel panel-default">
			<div class="panel-heading">Create New User</div>
			<div class="panel-body">
				<?= form_open_multipart('users/create',array('class'=>'form-horizontal')); ?>
				<?= form_input_horizontal(array('name'=>'f_name','label'=>'First Name :')); ?>
				<?= form_input_horizontal(array('name'=>'l_name','label'=>'Last Name :')); ?>
				<?= form_input_horizontal(array('name'=>'email','label'=>'Email :')); ?>
				<?= form_input_horizontal(array('name'=>'username','label'=>'Username :')); ?>
				<?= form_input_horizontal(array('name'=>'password','label'=>'Password :')); ?>
				<?= form_input_horizontal(array('name'=>'phone_no','label'=>'Phone No :')); ?>
				<?= form_textarea_horizontal(array('name'=>'address','label'=>'Address :')); ?>
				<?= form_input_horizontal(array('name'=>'city','label'=>'City :')); ?>
				<?= file_input_horizontal(array('name'=>'profile_img','label'=>'Profile Image :')); ?>
				<?php 
				$options = array();
				foreach($user_roles as $role) {
					if($role->role_ID > $this->auth->user()->role_ID ) {
						$options[$role->role_ID] = $role->role_name;
					}
				}
				?>
				<?= form_dropdown_horizontal(array(
					'name'=>'role_id',
					'label'=>'User Role :',
					'options'=> $options,
					'placeholder'=> 'Select a User Role'
					)); ?>
				<br/>
				<div class="row">
					<div class="col-xs-11">
				<?= form_submit(array('value'=>'create')); ?>
					</div>
				</div>
				<br/>
				<?= form_close(); ?>	
			</div>	
		</div>
	</div>
</div>
